# CHANGELOG

## 0.1.6 
* fixed issue with new image link structure (Issue #30)
## 0.1.5 
* fixed issue "looks strange, ignoring" related to imageio version (Issue #22)
## 0.1.4 
* prevent crash if raw images cannot be saved. (Issue #18)
## 0.1.3
* fixed issue with finding measures for some sheets. (Issue #19)
## 0.1.2
* fixed inverted colors bug 
## 0.1.0
* first version on PyPI
    * changed setup structure
* attempt to fix issue #15: All patches being ignored
